From: blaisorblade@yahoo.it
To: akpm@osdl.org
Cc: linux-kernel@vger.kernel.org, blaisorblade@yahoo.it, dhowells@redhat.com
Subject: [patch 1/1] fix syscallN() macro errno value checking for i386
Date: Sat, 29 Jan 2005 02:01:43 +0100 [thread overview]
Message-ID: <20050129010145.1C42F8C9E4@zion> (raw)
From: Paolo 'Blaisorblade' Giarrusso <blaisorblade@yahoo.it>
Cc: David Howells <dhowells@redhat.com>
The errno values which are visible for userspace are actually in the range
-1 - -129, not until -128 (): this value was added:
#define EKEYREJECTED 129 /* Key was rejected by service */
And this would break ucLibc (for what I heard).
This is just a quick-fix, because putting a macro inside errno.h instead of
having it copied in two places would be probably nicer.
However, I've heard by D. Howells it wasn't accepted, so this is the solution for now.
Signed-off-by: Paolo 'Blaisorblade' Giarrusso <blaisorblade@yahoo.it>
---
linux-2.6.11-paolo/include/asm-i386/unistd.h | 6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)
diff -puN include/asm-i386/unistd.h~fix-syscall-macro include/asm-i386/unistd.h
--- linux-2.6.11/include/asm-i386/unistd.h~fix-syscall-macro 2005-01-29 00:42:48.000000000 +0100
+++ linux-2.6.11-paolo/include/asm-i386/unistd.h 2005-01-29 00:44:51.000000000 +0100
@@ -298,12 +298,12 @@
#define NR_syscalls 289
/*
* user-visible error numbers are in the range -1 - -128: see
* <asm-i386/errno.h>
*/
#define __syscall_return(type, res) \
do { \
- if ((unsigned long)(res) >= (unsigned long)(-(128 + 1))) { \
+ if ((unsigned long)(res) >= (unsigned long)(-(129 + 1))) { \
errno = -(res); \
res = -1; \
} \
_
next reply other threads:[~2005-01-29 1:02 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2005-01-29 1:01 blaisorblade [this message]
2005-01-30 17:00 ` [patch 1/1] fix syscallN() macro errno value checking for i386 Arnd Bergmann
2005-01-30 18:30 ` jerome lacoste
2005-02-04 0:36 ` H. Peter Anvin
2005-03-05 17:59 ` Blaisorblade
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20050129010145.1C42F8C9E4@zion \
--to=blaisorblade@yahoo.it \
--cc=akpm@osdl.org \
--cc=dhowells@redhat.com \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -298,12 +298,12 @@
#define NR_syscalls 289
/*
- * user-visible error numbers are in the range -1 - -128: see
- * <asm-i386/errno.h>
+ * user-visible error numbers are in the range -1 - -129: see
+ * <asm-i386/errno.h> (currently it includes <asm-generic/errno.h>)
*/
#define __syscall_return(type, res) \
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.